@@ -153,13 +153,6 @@ bool Kwave::FileContext::createMainWidget(const QSize &preferred_size)
 	    this, SLOT(visibleRangeChanged(sample_index_t,
 	    sample_index_t, sample_index_t)) );
 
-    connect(m_main_widget,
-	    SIGNAL(sigMouseChanged(Kwave::MouseMark::Mode,
-	                           sample_index_t, sample_index_t)),
-            m_top_widget,
-	    SLOT(mouseChanged(Kwave::MouseMark::Mode,
-	                      sample_index_t, sample_index_t)));
-
     return true;
 }
 
@@ -883,9 +876,16 @@ int Kwave::FileContext::revert()
     Kwave::FileContext::UsageGuard _keep(this);
 
     QUrl url(signalName());
-    if (!url.isValid()) return -EINVAL;
+    if (!url.isValid() || !m_signal_manager) return -EINVAL;
 
-    return (m_signal_manager) ? m_signal_manager->loadFile(url) : -EINVAL;
+    if (m_signal_manager->isModified()) {
+        int res =  Kwave::MessageBox::warningContinueCancel(m_top_widget,
+            i18n("This file has been modified, changes will be lost.\n"
+                 "Do you want to continue?"));
+        if (res == KMessageBox::Cancel) return ECANCELED;
+    }
+
+    return m_signal_manager->loadFile(url);
 }
 
 //***************************************************************************
