@@ -108,42 +108,42 @@ namespace Kwave
 	virtual ~MainWidget();
 
 	/** Returns the current zoom factor [samples/pixel] */
-	virtual double zoom() const;
+	double zoom() const Q_DECL_OVERRIDE;
 
 	/** Returns the width of the current view in pixels */
-	virtual int visibleWidth() const;
+	int visibleWidth() const Q_DECL_OVERRIDE;
 
 	/** Returns the width of the current view in samples */
-	virtual sample_index_t visibleSamples() const;
+	sample_index_t visibleSamples() const Q_DECL_OVERRIDE;
 
 	/** Returns the current start position of the visible area [samples] */
 	virtual sample_index_t visibleOffset() { return m_offset; }
 
 	/** Returns the preferred size of the widget */
-	virtual QSize sizeHint () const { return m_preferred_size; }
+	QSize sizeHint () const Q_DECL_OVERRIDE { return m_preferred_size; }
 
     protected:
 
 	/** @see Qt XDND documentation */
-	virtual void dragEnterEvent(QDragEnterEvent *event);
+	void dragEnterEvent(QDragEnterEvent *event) Q_DECL_OVERRIDE;
 
 	/**
 	 * For dropping data into an empty signal
 	 * @see Qt XDND documentation
 	 */
-	virtual void dropEvent(QDropEvent *event);
+	void dropEvent(QDropEvent *event) Q_DECL_OVERRIDE;
 
 	/**
 	 * Called if the main widget has been resized and resizes/moves
 	 * the signal widget and the channel controls
 	 */
-	virtual void resizeEvent(QResizeEvent *event);
+	void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
 
 	/** slot for mouse wheel events, for scrolling/zooming */
-	virtual void wheelEvent(QWheelEvent *event);
+	void wheelEvent(QWheelEvent *event) Q_DECL_OVERRIDE;
 
 	/** @see QWidget::closeEvent() */
-	virtual void closeEvent(QCloseEvent *e);
+	void closeEvent(QCloseEvent *e) Q_DECL_OVERRIDE;
 
     protected slots:
 
@@ -159,7 +159,7 @@ namespace Kwave
 	 * @retval -ENOSYS is returned if the command is unknown in this
 	 *                 component
 	 */
-	virtual int executeCommand(const QString &command);
+	int executeCommand(const QString &command) Q_DECL_OVERRIDE;
 
 	/**
 	 * Sets the display offset [samples] and refreshes the screen.
@@ -172,7 +172,7 @@ namespace Kwave
 	 * Scrolls the display so that the given position gets visible,
 	 * centered within the display if possible.
 	 */
-	virtual void scrollTo(sample_index_t pos);
+	void scrollTo(sample_index_t pos) Q_DECL_OVERRIDE;
 
 	/**
 	 * sets a new zoom factor [samples/pixel], does not refresh the screen
@@ -180,7 +180,7 @@ namespace Kwave
 	 *                 to [length/width...1/width] (from full display to
 	 *                 one visible sample only)
 	 */
-	void setZoom(double new_zoom);
+	void setZoom(double new_zoom) Q_DECL_OVERRIDE;
 
 	/**
 	 * Zooms into the selected range between the left and right marker.
