@@ -199,7 +199,7 @@ namespace Kwave
 	 * @retval false if saving undo data failed, e.g. out of memory
 	 *               or aborted
 	 */
-	virtual bool saveUndoData(Kwave::UndoTransaction &undo);
+	bool saveUndoData(Kwave::UndoTransaction &undo) Q_DECL_OVERRIDE;
 
     private:
 
@@ -222,7 +222,7 @@ namespace Kwave
 	    /**
 	     * Returns a verbose short description of the action.
 	     */
-	    virtual QString description();
+	    QString description() Q_DECL_OVERRIDE;
 
 	    /**
 	     * Returns the required amount of memory that is needed for storing
@@ -230,13 +230,13 @@ namespace Kwave
 	     * free memory to be reserved.
 	     * @note this is the first step (after the constructor)
 	     */
-	    virtual qint64 undoSize();
+	    qint64 undoSize() Q_DECL_OVERRIDE;
 
 	    /**
 	     * Returns the difference of needed memory that is needed for
 	     * redo.
 	     */
-	    virtual qint64 redoSize();
+	    qint64 redoSize() Q_DECL_OVERRIDE;
 
 	    /**
 	     * Stores the data needed for undo.
@@ -244,7 +244,7 @@ namespace Kwave
 	     * @note this is the second step, after size() has been called
 	     * @return true if successful, false if failed (e.g. out of memory)
 	     */
-	    virtual bool store(Kwave::SignalManager &manager);
+	    bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
 
 	    /**
 	     * Takes back an action by creating a new undo action (for further
@@ -256,18 +256,18 @@ namespace Kwave
 	     *       undo/redo. You have to check for this when deleting an
 	     *       UndoAction object after undo.
 	     */
-	    virtual Kwave::UndoAction *undo(Kwave::SignalManager &manager,
-	                                    bool with_redo);
+	    Kwave::UndoAction *undo(Kwave::SignalManager &manager,
+	                                    bool with_redo) Q_DECL_OVERRIDE;
 
 	    /**
 	     * This undo action does not contribute to the modification
 	     * of the signal.
 	     * @return true always
 	     */
-	    virtual bool containsModification() const { return false; }
+	    bool containsModification() const Q_DECL_OVERRIDE { return false; }
 
 	    /** dump, for debugging purposes */
-	    virtual void dump(const QString &indent) {
+	    void dump(const QString &indent) Q_DECL_OVERRIDE {
 		qDebug("%s%s", DBG(indent), DBG(description()));
 	    }
 
