@@ -53,20 +53,20 @@ namespace Kwave
 	/**
 	 * Returns a verbose short description of the action.
 	 */
-	virtual QString description();
+	QString description() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::undoSize() */
-	virtual qint64 undoSize();
+	qint64 undoSize() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::redoSize() */
-	virtual qint64 redoSize();
+	qint64 redoSize() Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::store() */
-	virtual bool store(SignalManager &manager);
+	bool store(SignalManager &manager) Q_DECL_OVERRIDE;
 
 	/** @see UndoAction::undo() */
-	virtual Kwave::UndoAction *undo(Kwave::SignalManager &manager,
-	                                bool with_redo);
+	Kwave::UndoAction *undo(Kwave::SignalManager &manager,
+	                        bool with_redo) Q_DECL_OVERRIDE;
 
     protected:
 
