@@ -61,7 +61,7 @@ Kwave::OpusDecoder::OpusDecoder(QIODevice *source,
      m_oy(oy), m_os(os), m_og(og), m_op(op), m_opus_decoder(0),
      m_comments_map(), m_raw_buffer(0), m_buffer(0),
      m_rate_converter(0),
-     m_converter_connected(false),
+     m_output_is_connected(false),
      m_packet_count(0), m_samples_raw(0), m_bytes_count(0),
      m_packet_len_min(0), m_packet_len_max(0),
      m_packet_size_min(0), m_packet_size_max(0),
@@ -154,7 +154,7 @@ int Kwave::OpusDecoder::parseOpusTags(QWidget *widget, Kwave::FileInfo &info)
 	ogg_sync_wrote(&m_oy, static_cast<long int>(bytes));
     }
 
-    unsigned int packet = 0;
+    bool first_packet = true;
     unsigned int fields = 0;
     while (ogg_stream_packetout(&m_os, &m_op) == 1) {
 	const unsigned char *c   = m_op.packet;
@@ -173,7 +173,7 @@ int Kwave::OpusDecoder::parseOpusTags(QWidget *widget, Kwave::FileInfo &info)
 	c      += 8;
 	length -= 8;
 
-	if (packet == 0) {
+	if (first_packet) {
 	    // the start of the first packet contains the software
 
 	    // read length of the comment
@@ -184,7 +184,7 @@ int Kwave::OpusDecoder::parseOpusTags(QWidget *widget, Kwave::FileInfo &info)
 		// comment extends beyond end of packet
 		qWarning("OpusDecoder::parseHeader(): encoder name truncated "
 		         "(len=%u, max=%lu)", len, length);
-		len = length;
+		len = static_cast<quint32>(length);
 	    }
 	    QString encoder =
 		QString::fromUtf8(reinterpret_cast<const char *>(c), len);
@@ -201,6 +201,8 @@ int Kwave::OpusDecoder::parseOpusTags(QWidget *widget, Kwave::FileInfo &info)
 	    fields = qFromLittleEndian<quint32>(c);
 	    c      += 4;
 	    length -= 4;
+
+	    first_packet = false;
 	}
 
 	while (fields && (length > 4)) {
@@ -216,7 +218,7 @@ int Kwave::OpusDecoder::parseOpusTags(QWidget *widget, Kwave::FileInfo &info)
 		// comment extends beyond end of packet
 		qWarning("OpusDecoder::parseHeader(): comment truncated "
 		         "(len=%u, max=%lu)", len, length);
-		len = length;
+		len = static_cast<quint32>(length);
 	    }
 	    QString comment =
 		QString::fromUtf8(reinterpret_cast<const char *>(c), len);
@@ -367,7 +369,6 @@ int Kwave::OpusDecoder::parseOpusHead(QWidget *widget, Kwave::FileInfo &info)
     return 1;
 }
 
-
 //***************************************************************************
 int Kwave::OpusDecoder::open(QWidget *widget, Kwave::FileInfo &info)
 {
@@ -507,7 +508,10 @@ int Kwave::OpusDecoder::decode(Kwave::MultiWriter &dst)
     // get some statistical data, for bitrate mode detection
     m_packet_count++;
 
-    int frames = opus_packet_get_nb_frames(m_op.packet, m_op.bytes);
+    int frames = opus_packet_get_nb_frames(
+	m_op.packet,
+	static_cast<opus_int32>(m_op.bytes)
+    );
     if(frames < 1 || frames > 48) {
 	qWarning("WARNING: Invalid packet TOC in packet #%llu",
 	         static_cast<unsigned long long int>(m_op.packetno));
@@ -521,8 +525,10 @@ int Kwave::OpusDecoder::decode(Kwave::MultiWriter &dst)
 
     if (spp < m_packet_len_min) m_packet_len_min = spp;
     if (spp > m_packet_len_max) m_packet_len_max = spp;
-    if (m_op.bytes < m_packet_size_min) m_packet_size_min = m_op.bytes;
-    if (m_op.bytes > m_packet_size_max) m_packet_size_max = m_op.bytes;
+    if (m_op.bytes < m_packet_size_min)
+	m_packet_size_min = Kwave::toInt(m_op.bytes);
+    if (m_op.bytes > m_packet_size_max)
+	m_packet_size_max = Kwave::toInt(m_op.bytes);
 
     // total count of samples and bytes
     m_samples_raw += spp;
@@ -542,8 +548,9 @@ int Kwave::OpusDecoder::decode(Kwave::MultiWriter &dst)
     // decode the audio data into a buffer with float values
     int length = opus_multistream_decode_float(
 	m_opus_decoder,
-	static_cast<unsigned char *>(m_op.packet),
-	m_op.bytes, m_raw_buffer, MAX_FRAME_SIZE, 0
+	static_cast<const unsigned char *>(m_op.packet),
+	static_cast<opus_int32>(m_op.bytes),
+	m_raw_buffer, MAX_FRAME_SIZE, 0
     );
     if (length <= 0) {
 	qWarning("OpusDecoder::decode() failed: '%s'",
@@ -561,27 +568,20 @@ int Kwave::OpusDecoder::decode(Kwave::MultiWriter &dst)
 
     const unsigned int tracks = m_opus_header.channels;
 
-    bool ok = true;
-    if (m_rate_converter) {
-	if (!m_converter_connected) {
-	    ok = Kwave::connect(
-		*m_rate_converter, SIGNAL(output(Kwave::SampleArray)),
-		dst,               SLOT(input(Kwave::SampleArray)));
-	    m_converter_connected = true;
+    if (!m_output_is_connected) {
+	Kwave::StreamObject *src =
+	    (m_rate_converter) ? m_rate_converter : m_buffer;
+	if (!Kwave::connect(*src, SIGNAL(output(Kwave::SampleArray)),
+	                     dst, SLOT(input(Kwave::SampleArray))) )
+	{
+	    qWarning("OpusDecoder::decode() connecting output failed");
+	    return -1;
 	}
-    } else {
-	ok = Kwave::connect(
-	    *m_buffer, SIGNAL(output(Kwave::SampleArray)),
-	    dst,       SLOT(input(Kwave::SampleArray))
-	);
-    }
-    if (!ok) {
-	qWarning("OpusDecoder::decode() connecting converter failed");
-	return -1;
+	m_output_is_connected = true;
     }
 
     // handle preskip
-    float *p = m_raw_buffer;
+    const float *p = m_raw_buffer;
     if (m_preskip) {
 	if (m_preskip >= length) {
 	    m_preskip -= length;
@@ -606,14 +606,14 @@ int Kwave::OpusDecoder::decode(Kwave::MultiWriter &dst)
     // convert the buffer from float to sample_t, blockwise...
     for (unsigned int t = 0; t < tracks; t++) {
 	Kwave::SampleBuffer *buffer = m_buffer->at(t);
-	float    *in  = p + t;
+	const float         *in     = p + t;
 	for (int frame = 0; frame < length; frame++) {
-	    // scale, use some primitive noise shaping
-	    sample_t s = static_cast<sample_t>(
-		(*in) * static_cast<float>(SAMPLE_MAX) + drand48() - 0.5f);
-	    if (s > SAMPLE_MAX) s = SAMPLE_MAX;
-	    if (s < SAMPLE_MIN) s = SAMPLE_MIN;
-
+	    // scale, use some primitive noise shaping + clipping
+	    double   noise = (drand48() - double(0.5)) / double(SAMPLE_MAX);
+	    double   d     = static_cast<double>(*in);
+	    sample_t s     = qBound<sample_t>(
+		SAMPLE_MIN, double2sample(d + noise), SAMPLE_MAX
+	    );
 	    buffer->put(s);
 	    in += tracks;
 	}
@@ -660,7 +660,7 @@ void Kwave::OpusDecoder::close(Kwave::FileInfo &info)
     delete m_rate_converter;
     m_rate_converter = 0;
 
-    m_converter_connected = false;
+    m_output_is_connected = false;
 
     qDebug("    OpusDecoder: packet count=%u", m_packet_count);
     qDebug("    OpusDecoder: packet length: %d...%d samples",
