@@ -266,10 +266,10 @@ void Kwave::K3BExportPlugin::load(QStringList &params)
 {
     Q_UNUSED(params);
 
-    QString menu_path = _("File/Save/%1").arg(i18nc(
+    QString menu_path = _("File/Save/%1").arg(_(I18N_NOOP2(
 	"menu: /File/Save/Export to K3b Project...",
-	"Export to K3b Project..."
-    ));
+	                 "Export to K3b Project..."
+    )));
     emitCommand(_("menu(plugin:setup(export_k3b),%1%2)").arg(
 	menu_path).arg(_("/#group(@SIGNAL)")));
     emitCommand(_("menu(plugin:setup(export_k3b),%1%2)").arg(
