@@ -998,7 +998,6 @@ void Kwave::RecordPlugin::startRecording()
     if ((m_state != Kwave::REC_PAUSED) || !m_decoder) {
 	double rate = m_dialog->params().sample_rate;
 	unsigned int tracks = m_dialog->params().tracks;
-	unsigned int samples = 0;
 	unsigned int bits = m_dialog->params().bits_per_sample;
 
 	if (!tracks) return;
@@ -1012,8 +1011,8 @@ void Kwave::RecordPlugin::startRecording()
 	     Kwave::FileInfo(signalManager().metaData()).rate(), rate))
 	{
 	    // create a new and empty signal
-	    emitCommand(QString(_("newsignal(%1,%2,%3,%4)")).arg(
-		samples).arg(rate).arg(bits).arg(tracks));
+	    emitCommand(QString(_("newsignal(0,%1,%2,%3)")).arg(
+		rate).arg(bits).arg(tracks));
 	    QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
 
 	    // the parent context might have changed, maybe we have to
@@ -1058,7 +1057,7 @@ void Kwave::RecordPlugin::startRecording()
 	const KAboutData about_data = KAboutData::applicationData();
 	QString software = about_data.componentName() + _("-") +
 	                   about_data.version() + _(" ") +
-	                   i18n("(built for KDE Frameworks %1)",
+	                   i18n("(built with KDE Frameworks %1)",
 	                   _(KXMLGUI_VERSION_STRING));
 	fileInfo.set(Kwave::INF_SOFTWARE, software);
 
